## Automatically adapted for numpy.oldnumeric Feb 04, 2011 by 

# Name: xdp/io/text.py
# Purpose: I/O support for plain text files
# Author: Ken McIvor <mcivken@iit.edu>
#
# Copyright 2003-2005 Illinois Institute of Technology
#
# See the file "LICENSE" for information on usage and redistribution
# of this file, and for a DISCLAIMER OF ALL WARRANTIES.

"""
Read and write plain-text files of data.

Any lines at the start of the file beginning with the symbols '#', '!', or ';'
are treated as headers and discarded.
"""


import xdp
import _matrixio
import numpy.oldnumeric as Numeric



class Text:
    """
    The (empty) header of a plain-text file.
    """

    def write(self, data, stream):
        """
        Write a dataset to an output stream in plain-text.  Any associated
        metadata, including the column names, will not be written.

        @param data: dataset
        @type  data: C{Data}
        @param stream: output stream
        @type  stream: C{file}
        """

        _matrixio.write(stream, data.getMatrix())


def readTextFile(stream, comments='#!;'):
    """
    Read plain-text data from an input stream.

    @param stream: input stream
    @type  stream: C{file}
    @param comments: comment-delimiting characters (defaults to I{#!;})
    @type  comments: C{str}ing
    @return: header and data
    @rtype:  C{2-tuple} of the form C{(header, data)}

    @raise IOError: the data was malformed

    @note: This function will fail on input streams which don't support the
    C{seek} method.

    @note: The columns in the resulting dataset are named I{column##}.
    """

    while 1:
        c = stream.read(1)
        if c in comments:
            stream.readline()
        elif c != '':
            stream.seek(-1, 1)
            break

    header = Text()
    data = xdp.Data()

    try:
        dataMatrix = _matrixio.read(stream)
    except _matrixio.error, e:
        raise IOError(str(e))

    columns = [ 'column%s' % x for x in range(1, dataMatrix.shape[1]+1) ]

    for i in range(0, dataMatrix.shape[1]):
        data.add(columns[i], Numeric.ravel(dataMatrix[:, i]))

    return header, data
